@@ -11,7 +11,7 @@ use Mojo::Util qw(encode sha1_sum);
 sub current_user_fn { return 'user' }
 
 # Display the form for signing in.
-# GET /входъ
+# GET /in
 sub form($c) {
 
   #TODO: remember where the user is comming from to redirect him back
@@ -22,7 +22,7 @@ sub form($c) {
 }
 
 # Sign in the user.
-# POST /входъ
+# POST /in
 sub sign_in($c) {
 
   #1. do basic validation first
@@ -59,7 +59,7 @@ sub sign_in($c) {
   return $c->render('auth/form');
 }
 
-# GET /изходъ
+# GET /out
 sub sign_out ($c) {
   my $login_name = $c->user->{login_name};
   $c->logout;
@@ -89,7 +89,7 @@ sub under_management($c) {
 
   # only admins and users with id=created_by can change another's user account
   my ($e_uid) = $path =~ m|/users/(\d+)|;    #Id of the user being edited
-  my $e_user = $e_uid ? $c->users->find_where({id => $e_uid}) : undef;
+  my $e_user  = $e_uid ? $c->users->find_where({id => $e_uid}) : undef;
   if ( $route =~ /^(show|edit|update|remove)_users$/x
     && $e_user
     && ($e_user->{created_by} != $uid && $e_user->{id} != $uid))
@@ -102,7 +102,7 @@ sub under_management($c) {
   return 1;
 }
 
-# secure route /Ꙋправленѥ/minion.
+# secure route /manage/minion.
 # Allow access to only authenticated members of the admin group.
 sub under_minion($c) {
 
@@ -144,7 +144,7 @@ sub validate_user ($c, $login_name, $csrf_digest, $dat) {
     my $row = $c->dbx->db->select(
       passw_login => 'token',
       {start_date => {'<=' => $t}, to_uid => $u->{id}, stop_date => {'>' => $t}},
-      {-desc => ['id']})->hash;
+      {-desc      => ['id']})->hash;
     my $checksum2 = sha1_sum(
       $csrf_token . sha1_sum(encode('UTF-8' => $u->{login_name} . $row->{token})));
     if ($row && ($checksum2 eq $csrf_digest)) {
@@ -169,8 +169,8 @@ sub validate_user ($c, $login_name, $csrf_digest, $dat) {
 
 my $msg_expired_token = 'Връзката, която ви доведе тук, е с изтекла годност.' . '';
 
-# GET /първи-входъ/<token:fl_token>
-# GET /първи-входъ/32e36608c72bc51c7c39a72fd7e71cba55f3e9ad
+# GET /first_login/<token:fl_token>
+# GET /first_login/32e36608c72bc51c7c39a72fd7e71cba55f3e9ad
 sub first_login_form ($c) {
   $c->logout && $c->user($c->users->find_by_login_name('guest'))
     if $c->is_user_authenticated;
@@ -188,7 +188,7 @@ sub first_login_form ($c) {
   return $c->render(row => $row);
 }
 
-# POST /първи-входъ
+# POST /first_login
 sub first_login($c) {
   state $app = $c->app;
   my $token = $c->param('token');
@@ -232,7 +232,7 @@ sub first_login($c) {
   return $c->redirect_to('edit_users' => {id => $row->{to_uid}});
 }
 
-# GET /загубенъ-ключъ
+# GET /lost_password
 sub lost_password_form ($c) {
   if ($c->req->method eq 'POST') {
     my $v = $c->validation;
@@ -281,7 +281,7 @@ Mojolicious::Plugin::Authentication implements the following actions.
 Displays a form for confirmation of the names of the user who invited the new
 user.
 
-    GET /първи-входъ/<token:fl_token>
+    GET /first_login/<token:fl_token>
 
 C<fl_token> is a route type matching C<qr/[a-f0-9]{40}/>.
 
@@ -292,7 +292,7 @@ checks. Signs in the user for the first time.
 
 =head2 form
 
-Route: C<{get =E<gt> '/входъ', to =E<gt> 'auth#form', name =E<gt> 'authform'}>.
+Route: C<{get =E<gt> '/in', to =E<gt> 'auth#form', name =E<gt> 'authform'}>.
 
 Renders a login form. The password is never transmitted in plain text. A digest
 is prepared in the browser using JavaScript (see
@@ -304,7 +304,7 @@ compared on the server side. The digest is different in every POST request.
 Route:
 
    {
-    any  => '/загубенъ-ключъ',
+    any  => '/lost_password',
     to   => 'auth#lost_password_form',
     name => 'lost_password_form'
    },
@@ -316,7 +316,7 @@ user with the given email is found in the database.
 
 =head2 sign_in
 
-Route: C<{post =E<gt> '/входъ', to =E<gt> 'auth#sign_in', name =E<gt> 'sign_in'}>.
+Route: C<{post =E<gt> '/in', to =E<gt> 'auth#sign_in', name =E<gt> 'sign_in'}>.
 
 Finds and logs in a user locally. On success redirects the user to
 L<home_upravlenie|Slovo::Cotroller::Upravlenie/index>. On failure redirects
@@ -324,7 +324,7 @@ again to the login page.
 
 =head2 under_management
 
-This is a callback when user tries to access a page I<under> C</Ꙋправленѥ>. If
+This is a callback when user tries to access a page I<under> C</manage>. If
 user is authenticated returns true. If not, returns false and redirects to
 L</form>.
 
@@ -334,7 +334,7 @@ L</form>.
 Allow access to only authenticated members of the admin group. All routes
 generated by L<Minion::Admin> are under this route. 
 
-    GET /Ꙋправленѥ/minion
+    GET /manage/minion
 
 
 =head2 METHODS
@@ -373,4 +373,3 @@ L<Mojolicious::Plugin::Authentication>,
 L<Slovo::Task::SendOnboardingEmail>
 
 =cut
-
